package com.ruoyi.framework.recovery.service;

import java.util.List;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.framework.recovery.domain.RecBrand;
import com.ruoyi.framework.recovery.domain.vo.TreeSelectVo;

/**
 * 回收品牌Service接口
 *
 * @author jin
 * @date 2024-11-16
 */
public interface IRecBrandService
{
    /**
     * 查询回收品牌
     *
     * @param id 回收品牌主键
     * @return 回收品牌
     */
    public RecBrand selectRecBrandById(Long id);

    /**
     * 查询回收品牌列表
     *
     * @param recBrand 回收品牌
     * @return 回收品牌集合
     */
    public List<RecBrand> selectRecBrandList(RecBrand recBrand);

    /**
     * 新增回收品牌
     *
     * @param recBrand 回收品牌
     * @return 结果
     */
    public int insertRecBrand(RecBrand recBrand);

    /**
     * 修改回收品牌
     *
     * @param recBrand 回收品牌
     * @return 结果
     */
    public int updateRecBrand(RecBrand recBrand);

    /**
     * 批量删除回收品牌
     *
     * @param ids 需要删除的回收品牌主键集合
     * @return 结果
     */
    public int deleteRecBrandByIds(Long[] ids);

    /**
     * 删除回收品牌信息
     *
     * @param id 回收品牌主键
     * @return 结果
     */
    public int deleteRecBrandById(Long id);

    /**
     * 构建前端所需树结构
     *
     * @param list 品牌列表
     * @return 下拉树结构
     */
    List<TreeSelectVo> buildBrandSelect(List<RecBrand> list);
}
