package com.ruoyi.framework.recovery.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.framework.recovery.domain.RecBrand;
import com.ruoyi.framework.recovery.service.IRecBrandService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 回收品牌Controller
 *
 * @author jin
 * @date 2024-11-16
 */
@RestController
@RequestMapping("/recovery/brand")
public class RecBrandController extends BaseController
{
    @Autowired
    private IRecBrandService recBrandService;

    /**
     * 查询回收品牌列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:brand:list')")
    @GetMapping("/list")
    public AjaxResult list(RecBrand recBrand)
    {
        List<RecBrand> list = recBrandService.selectRecBrandList(recBrand);
        return AjaxResult.success(list);
    }

    /**
     * 查询品牌下拉树列表
     */
    @GetMapping("/tree/select")
    public AjaxResult treeselect(RecBrand recBrand)
    {
        List<RecBrand> list = recBrandService.selectRecBrandList(recBrand);
        return AjaxResult.success(recBrandService.buildBrandSelect(list));
    }

    /**
     * 导出回收品牌列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:brand:export')")
    @Log(title = "回收品牌", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecBrand recBrand)
    {
        List<RecBrand> list = recBrandService.selectRecBrandList(recBrand);
        ExcelUtil<RecBrand> util = new ExcelUtil<RecBrand>(RecBrand.class);
        util.exportExcel(response, list, "回收品牌数据");
    }

    /**
     * 获取回收品牌详细信息
     */
    @PreAuthorize("@ss.hasPermi('recovery:brand:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(recBrandService.selectRecBrandById(id));
    }

    /**
     * 新增回收品牌
     */
    @PreAuthorize("@ss.hasPermi('recovery:brand:add')")
    @Log(title = "回收品牌", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecBrand recBrand)
    {
        return toAjax(recBrandService.insertRecBrand(recBrand));
    }

    /**
     * 修改回收品牌
     */
    @PreAuthorize("@ss.hasPermi('recovery:brand:edit')")
    @Log(title = "回收品牌", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecBrand recBrand)
    {
        return toAjax(recBrandService.updateRecBrand(recBrand));
    }

    /**
     * 删除回收品牌
     */
    @PreAuthorize("@ss.hasPermi('recovery:brand:remove')")
    @Log(title = "回收品牌", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(recBrandService.deleteRecBrandByIds(ids));
    }
}
